# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKVideoCorePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkTemporalDataObjectPython
else:
    import _itkTemporalDataObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkTemporalRegionPython

def itkTemporalDataObject_New():
    return itkTemporalDataObject.New()

class itkTemporalDataObject(itk.ITKCommonBasePython.itkDataObject):
    r"""Proxy of C++ itkTemporalDataObject class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTemporalDataObject_Pointer"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTemporalDataObject_Pointer"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_Clone(self)

    def GetTemporalUnit(self):
        r"""GetTemporalUnit(self) -> itkTemporalDataObjectEnums::TemporalUnit"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetTemporalUnit(self)

    def SetTemporalUnitToFrame(self):
        r"""SetTemporalUnitToFrame(self)"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetTemporalUnitToFrame(self)

    def SetTemporalUnitToRealTime(self):
        r"""SetTemporalUnitToRealTime(self)"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetTemporalUnitToRealTime(self)

    def SetTemporalUnitToFrameAndRealTime(self):
        r"""SetTemporalUnitToFrameAndRealTime(self)"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetTemporalUnitToFrameAndRealTime(self)

    def GetNumberOfBuffers(self):
        r"""GetNumberOfBuffers(self) -> unsigned long"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetNumberOfBuffers(self)

    def SetNumberOfBuffers(self, num):
        r"""
        SetNumberOfBuffers(self, num)

        Parameters
        ----------
        num: unsigned long

        """
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetNumberOfBuffers(self, num)

    def SetLargestPossibleTemporalRegion(self, region):
        r"""
        SetLargestPossibleTemporalRegion(self, region)

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetLargestPossibleTemporalRegion(self, region)

    def GetLargestPossibleTemporalRegion(self):
        r"""GetLargestPossibleTemporalRegion(self) -> itkTemporalRegion"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetLargestPossibleTemporalRegion(self)

    def SetBufferedTemporalRegion(self, region):
        r"""
        SetBufferedTemporalRegion(self, region)

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetBufferedTemporalRegion(self, region)

    def GetBufferedTemporalRegion(self):
        r"""GetBufferedTemporalRegion(self) -> itkTemporalRegion"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetBufferedTemporalRegion(self)

    def SetRequestedTemporalRegion(self, region):
        r"""
        SetRequestedTemporalRegion(self, region)

        Parameters
        ----------
        region: itkTemporalRegion const &

        """
        return _itkTemporalDataObjectPython.itkTemporalDataObject_SetRequestedTemporalRegion(self, region)

    def GetRequestedTemporalRegion(self):
        r"""GetRequestedTemporalRegion(self) -> itkTemporalRegion"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetRequestedTemporalRegion(self)

    def GetUnbufferedRequestedTemporalRegion(self):
        r"""GetUnbufferedRequestedTemporalRegion(self) -> itkTemporalRegion"""
        return _itkTemporalDataObjectPython.itkTemporalDataObject_GetUnbufferedRequestedTemporalRegion(self)
    __swig_destroy__ = _itkTemporalDataObjectPython.delete_itkTemporalDataObject

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTemporalDataObject

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTemporalDataObjectPython.itkTemporalDataObject_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTemporalDataObject

        Create a new object of the class itkTemporalDataObject and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTemporalDataObject.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTemporalDataObject.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTemporalDataObject.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTemporalDataObject in _itkTemporalDataObjectPython:
_itkTemporalDataObjectPython.itkTemporalDataObject_swigregister(itkTemporalDataObject)
class itkTemporalDataObjectEnums(object):
    r"""Proxy of C++ itkTemporalDataObjectEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    TemporalUnit_Frame = _itkTemporalDataObjectPython.itkTemporalDataObjectEnums_TemporalUnit_Frame
    
    TemporalUnit_RealTime = _itkTemporalDataObjectPython.itkTemporalDataObjectEnums_TemporalUnit_RealTime
    
    TemporalUnit_FrameAndRealTime = _itkTemporalDataObjectPython.itkTemporalDataObjectEnums_TemporalUnit_FrameAndRealTime
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkTemporalDataObjectEnums
        __init__(self, arg0) -> itkTemporalDataObjectEnums

        Parameters
        ----------
        arg0: itkTemporalDataObjectEnums const &

        """
        _itkTemporalDataObjectPython.itkTemporalDataObjectEnums_swiginit(self, _itkTemporalDataObjectPython.new_itkTemporalDataObjectEnums(*args))
    __swig_destroy__ = _itkTemporalDataObjectPython.delete_itkTemporalDataObjectEnums

# Register itkTemporalDataObjectEnums in _itkTemporalDataObjectPython:
_itkTemporalDataObjectPython.itkTemporalDataObjectEnums_swigregister(itkTemporalDataObjectEnums)

